==> gcstar_1.1.1.orig.tar.gz: gcstar/lib/gcstar/GCLang/CA/GCModels/GCbooks.pm <==
{
    package GCLang::CA::GCModels::GCbooks;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Col·lecció de llibres',
        Items => 'Llibres',
        NewItem => 'Nou llibre',
    
        Isbn => 'ISBN',
        Title => 'Títol',
        Cover => 'Coberta',
        Authors => 'Autors',
        Publisher => 'Editorial',
        Publication => 'Data publicació',
        Language => 'Idioma',
        Genre => 'Gènere',
        Bookdescription => 'Descripció',
        Pages => 'Pàgines',
        Read => 'Llegit',
        Rating => 'Valoració',
        Acquisition => 'Data d\'adquisició',
        Edition => 'Edició',
        Format => 'Format',
        Comments => 'Comentaris',
        Url => 'Pàgina Web',
        Translator => 'Translator',
        Artist => 'Artist',

        General => 'General',
        Details => 'Detalls',

        ReadNo => 'Sense llegir',
        ReadYes => 'Llegit',
     );
}

1;

==> gcstar_1.3.2.orig.tar.gz: gcstar/lib/gcstar/GCLang/CA/GCModels/GCbooks.pm <==
{
    package GCLang::CA::GCModels::GCbooks;

    use utf8;
###################################################
#
#  Copyright 2005-2007 Tian
#
#  This file is part of GCstar.
#
#  GCstar is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  GCstar is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with GCstar; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
###################################################
    
    use strict;
    use base 'Exporter';

    our @EXPORT = qw(%lang);

    our %lang = (
    
        CollectionDescription => 'Col·lecció de llibres',
        Items => 'Llibres',
        NewItem => 'Nou llibre',
    
        Isbn => 'ISBN',
        Title => 'Títol',
        Cover => 'Coberta',
        Authors => 'Autors',
        Publisher => 'Editorial',
        Publication => 'Data de publicació',
        Language => 'Idioma',
        Genre => 'Gènere',
        Serie => 'Sèrie',
        Bookdescription => 'Descripció',
        Pages => 'Pàgines',
        Read => 'Llegit',
        Acquisition => 'Data d\'adquisició',
        Edition => 'Edició',
        Format => 'Format',
        Comments => 'Comentaris',
        Url => 'Pàgina Web',
        Translator => 'Translator',
        Artist => 'Artist',

        General => 'General',
        Details => 'Detalls',

        ReadNo => 'Sense llegir',
        ReadYes => 'Llegit',
     );
}

1;
